@@ -778,7 +778,7 @@ static float fogRGBDefault[4] = {0., 0., 0., 1.};
 static float fogStartEndDefault[2] = {0.3, 0.7};
 static gboolean fogIsOn;
 static gboolean fogHasBeenBuilt;
-static gulong nearFar_signal;
+static gulong nearFar_signal = 0;
 
 /* Callbacks. */
 static void rebuildFogOnResources(GObject *obj, VisuData *dataObj, gpointer data);
@@ -788,6 +788,16 @@ static void onDataNotReadySignal(GObject *visu, VisuData *dataObj,
                                  VisuGlView *view, gpointer data);
 static void onFogParameterChanged(VisuGlView *view, gpointer data);
 
+/**
+ * visu_gl_ext_fog_init: (skip)
+ *
+ * It initialises all variables of the OpenGL extension.
+ * It creates all resources and parameters introduced by
+ * this extension.
+ *
+ * Returns: a pointer to the VisuGlExt it created or
+ * NULL otherwise.
+ */
 void visu_gl_ext_fog_init()
 {
   visu_config_file_addEntry(VISU_CONFIG_FILE_RESOURCE,
@@ -825,8 +835,23 @@ void visu_gl_ext_fog_init()
 		   G_CALLBACK(onDataNotReadySignal), (gpointer)0);
 }
 
-/* Method used to change the value of the parameter fog. */
-int visu_gl_ext_fog_setValues(float rgba[4], int mask)
+/**
+ * visu_gl_ext_fog_setValues:
+ * @rgba: (in) (array fixed-size=4): a three floats array with
+ * values (0 <= values <= 1) for the red, the green and the blue
+ * color. Only values specified by the mask are really relevant.
+ * @mask: use #TOOL_COLOR_MASK_R, #TOOL_COLOR_MASK_G,
+ * #TOOL_COLOR_MASK_B, #TOOL_COLOR_MASK_RGBA or a combinaison to
+ * indicate what values in the rgb array must be taken into account.
+ *
+ * Method used to change the value of the parameter fog_specific_color.
+ * This color is actually used only if fog_color_is_specific is set to 1,
+ * use setFogColorSpecific() to do that.
+ *
+ * Returns: 0 if redrawing is not necessary.
+ * 1 if the rendering window must be redrawn.
+ */
+gboolean visu_gl_ext_fog_setValues(float rgba[4], int mask)
 {
   int diff = 0;
   
@@ -851,7 +876,7 @@ int visu_gl_ext_fog_setValues(float rgba[4], int mask)
       diff = 1;
     }
   if (!diff)
-    return 0;
+    return FALSE;
 
   /* The method which calls the set method should ask for redraw. */
   if (fogColorSpecific)
@@ -865,7 +890,15 @@ void visu_gl_ext_fog_getValues(float rgba[4])
 {
   memcpy(rgba, fogRGB, sizeof(float) * 4);
 }
-/* Method used to change the value of the parameter axes_is_on. */
+/**
+ * visu_gl_ext_fog_setOn:
+ * @value: TRUE if fog must be rendered, FALSE otherwise.
+ *
+ * Method used to change the value of the parameter fog_is_on.
+ *
+ * Returns: FALSE if redrawing is not necessary.
+ * TRUE if the rendering window must be redrawn.
+ */
 gboolean visu_gl_ext_fog_setOn(gboolean value)
 {
   if (value == fogIsOn)
@@ -888,6 +921,17 @@ gboolean visu_gl_ext_fog_getOn()
 {
   return fogIsOn;
 }
+/**
+ * visu_gl_ext_fog_setUseSpecificColor:
+ * @value: TRUE if fog is rendered with its own color specified
+ * by setFogRGBValues() or FALSE if the fog uses the background
+ * color.
+ *
+ * Method used to change the value of the parameter fog_color_is_specific.
+ *
+ * Returns: TRUE if visu_gl_ext_fog_create() should be called. In all cases, 'OpenGLAskForReDraw'
+ *          signal should then be emitted.
+ */
 gboolean visu_gl_ext_fog_setUseSpecificColor(gboolean value)
 {
   if (value == fogColorSpecific)
@@ -902,6 +946,21 @@ gboolean visu_gl_ext_fog_getUseSpecificColor()
 {
   return fogColorSpecific;
 }
+/**
+ * visu_gl_ext_fog_setStartEndValues:
+ * @startEnd: (in) (array fixed-size=2): a two floats array with
+ * values (0 <= values <= 1) for the beging and the ending of the fog
+ * position. Only values specified by the mask are really relevant.
+ * @mask: use #VISU_GL_EXT_FOG_MASK_START, #VISU_GL_EXT_FOG_MASK_END
+ * to indicate what values in the startEnd array must be taken into
+ * account.
+ *
+ * Method used to change the value of the parameters fog_start and
+ * fog_end.
+ *
+ * Returns: TRUE if visu_gl_ext_fog_create() should be called and then 'OpenGLAskForReDraw'
+ *          signal be emitted.
+ */
 gboolean visu_gl_ext_fog_setStartEndValues(float startEnd[2], int mask)
 {
   int diff = 0;
@@ -996,27 +1055,32 @@ static void rebuildFogOnResources(GObject *obj _U_, VisuData *dataObj _U_,
 	      " fog.\n");
   /* g_message("TODO: add a way to update fog when loading resources.\n"); */
 }
-static void onDataReadySignal(GObject *visu _U_, VisuData *dataObj,
+static void onDataReadySignal(GObject *visu _U_, VisuData *dataObj _U_,
                               VisuGlView *view, gpointer data _U_)
 {
-  if (dataObj && view)
+  VisuBox *box;
+
+  box = visu_boxed_getBox(VISU_BOXED(view));
+  if (view && box)
     {
-      visu_gl_ext_fog_create(view, visu_boxed_getBox(VISU_BOXED(dataObj)));
-      nearFar_signal =
-        g_signal_connect(G_OBJECT(view), "NearFarChanged",
-                         G_CALLBACK(onFogParameterChanged), (gpointer)dataObj);
+      visu_gl_ext_fog_create(view, box);
+      if (!nearFar_signal)
+        nearFar_signal =
+          g_signal_connect(G_OBJECT(view), "NearFarChanged",
+                           G_CALLBACK(onFogParameterChanged), (gpointer)0);
     }
 }
 static void onDataNotReadySignal(GObject *visu _U_, VisuData *dataObj _U_,
                                  VisuGlView *view, gpointer data _U_)
 {
   g_signal_handler_disconnect(G_OBJECT(view), nearFar_signal);
+  nearFar_signal = 0;
 }
-static void onFogParameterChanged(VisuGlView *view, gpointer data)
+static void onFogParameterChanged(VisuGlView *view, gpointer data _U_)
 {
   DBG_fprintf(stderr, "Extension Fog: caught the 'NearFarChanged' signal, rebuilding"
 	      " fog.\n");
-  visu_gl_ext_fog_create(view, visu_boxed_getBox(VISU_BOXED(data)));
+  visu_gl_ext_fog_create(view, visu_boxed_getBox(VISU_BOXED(view)));
 }
 
 /* Resources. */
