@@ -48,6 +48,7 @@
 #include <visu_object.h>
 #include <visu_tools.h>
 #include <gtk_pairs.h>
+#include <extensions/pairs.h>
 
 #include "cylinder.h"
 
@@ -55,6 +56,10 @@
  * SECTION: gtk_cylinder
  * @short_description: The additional widgets displayed in the pair
  * dialog to handle cylinder pairs.
+ *
+ * <para>Some additional widgets to be displayed in the pairs dialog
+ * window. It contains a tool to choose the colourisation scheme of
+ * pairs and the radius of cylinder representation.</para>
  */
 
 int colorForCurve;
@@ -71,14 +76,27 @@ void changeCylinderRadius(GtkSpinButton *spin, gpointer data);
 void changeCylinderColorType(GtkToggleButton *button, gpointer data);
 /* static void cylinderValuesChangedOnResources(GObject *obj, gpointer data); */
 
-void gtkPairsCylinderInit(void)
+/**
+ * visu_ui_pairs_cylinder_init: (skip)
+ *
+ * This routine is used by V_Sim to initialise the Gtk part of
+ * cylinder pair model. This should be called once on start-up.
+ */
+void visu_ui_pairs_cylinder_init(void)
 {
-/*   g_signal_connect(VISU_INSTANCE, "resourcesLoaded", */
+/*   g_signal_connect(VISU_OBJECT_INSTANCE, "resourcesLoaded", */
 /* 		   G_CALLBACK(cylinderValuesChangedOnResources), (gpointer)0); */
 }
 
-
-GtkWidget* gtkPairsCylinderBuild_widgets()
+/**
+ * visu_ui_pairs_cylinder_initBuild: (skip)
+ *
+ * This routine create a container #GtkWidget that hold all widgets
+ * necessary for handling cylinder pair model.
+ *
+ * Returns: a newly created #GtkWidget.
+ */
+GtkWidget* visu_ui_pairs_cylinder_initBuild()
 {
   GtkWidget *hbox, *vbox;
   GtkWidget *label;
@@ -92,10 +110,10 @@ GtkWidget* gtkPairsCylinderBuild_widgets()
   label = gtk_label_new(_("Radius:"));
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
-  spinCylinderRadius = gtk_spin_button_new_with_range(RESOURCES_CYLINDER_RADIUS_MIN,
-                                                      RESOURCES_CYLINDER_RADIUS_MAX,
+  spinCylinderRadius = gtk_spin_button_new_with_range(VISU_GL_PAIRS_CYLINDER_RADIUS_MIN,
+                                                      VISU_GL_PAIRS_CYLINDER_RADIUS_MAX,
                                                       RESOURCES_CYLINDER_RADIUS_STEP);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), cylinderGet_generalRadius());
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), visu_gl_pairs_cylinder_getGeneralRadius());
   gtk_box_pack_start(GTK_BOX(hbox), spinCylinderRadius, FALSE, FALSE, 0);
 
   hbox = gtk_hbox_new(FALSE, 0);
@@ -112,7 +130,7 @@ GtkWidget* gtkPairsCylinderBuild_widgets()
                              radioCylinderUser_group);
   radioCylinderUser_group =
     gtk_radio_button_get_group(GTK_RADIO_BUTTON(radioCylinderUser));
-  if(cylinderGet_colorType() == 0)
+  if(visu_gl_pairs_cylinder_getColorType() == 0)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioCylinderUser), TRUE);
 
   radioCylinderElement = gtk_radio_button_new_with_mnemonic(NULL, _("_elements"));
@@ -120,7 +138,7 @@ GtkWidget* gtkPairsCylinderBuild_widgets()
   gtk_box_pack_start(GTK_BOX(hbox), radioCylinderElement, FALSE, FALSE, 0);
   gtk_radio_button_set_group(GTK_RADIO_BUTTON(radioCylinderElement),
                              radioCylinderUser_group);
-  if (cylinderGet_colorType() == 1)
+  if (visu_gl_pairs_cylinder_getColorType() == 1)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioCylinderElement), TRUE);
 
   signalSpinCylinderRadiusId =
@@ -138,7 +156,7 @@ GtkWidget* gtkPairsCylinderBuild_widgets()
 void changeCylinderRadius(GtkSpinButton *spin, gpointer data _U_)
 {
   int res;
-  GtkPairsIter iter;
+  VisuUiPairsIter iter;
   gchar* label;
 
   res = FALSE;
@@ -146,21 +164,24 @@ void changeCylinderRadius(GtkSpinButton *spin, gpointer data _U_)
      we can build only one label and use it every time. */
   label = (gchar*)0;
   /* We run on all selected pairs. */
-  for (gtkPairsIter_startSelected(&iter); iter.data;
-       gtkPairsIter_nextSelected(&iter))
+  for (visu_ui_pairs_iter_startSelected(&iter); iter.data;
+       visu_ui_pairs_iter_nextSelected(&iter))
     {
       /* We change the value for this pair. */
-      res = cylinderSet_radius(iter.data,
+      res = visu_gl_pairs_cylinder_setRadius(iter.data,
 			      (float)gtk_spin_button_get_value(spin)) || res;
       if (!label)
-	label = gtkPairsCylinderGet_valuesAsLabel(iter.data);
+	label = visu_ui_pairs_cylinder_getValues(iter.data);
       /* We change the drawn label. */
-      gtkPairsSet_specificLabels(&(iter.iter), label);
+      visu_ui_pairs_setSpecificLabels(&(iter.iter), label);
     }
   g_free(label);
 
   if (res)
-    gtkPairs_createPairs();
+    {
+      visu_gl_ext_pairs_draw(visu_gl_ext_pairs_getDefault());
+      VISU_REDRAW_ADD;
+    }
 }
 
 void changeCylinderColorType(GtkToggleButton *button, gpointer data)
@@ -172,11 +193,14 @@ void changeCylinderColorType(GtkToggleButton *button, gpointer data)
     return;
   
   color = GPOINTER_TO_INT(data);
-  g_return_if_fail(color >= 0 && color < cylinder_nb_color);
+  g_return_if_fail(color >= 0 && color < VISU_GL_PAIRS_CYLINDER_N_COLOR);
 
-  res = cylinderSet_colorType(color);
+  res = visu_gl_pairs_cylinder_setColorType(color);
   if (res)
-    gtkPairs_createPairs();
+    {
+      visu_gl_ext_pairs_draw(visu_gl_ext_pairs_getDefault());
+      VISU_REDRAW_ADD;
+    }
 }
 
 /* static void cylinderValuesChangedOnResources(GObject *obj, gpointer data) */
@@ -187,49 +211,49 @@ void changeCylinderColorType(GtkToggleButton *button, gpointer data)
 /*     return; */
 
 /*   DBG_fprintf(stderr, "Gtk Cylinder : catch the 'resourcesLoaded' signal, updating values.\n"); */
-/*   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), cylinderGet_generalRadius()); */
-/*   val = cylinderGet_colorType(); */
+/*   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), visu_gl_pairs_cylinder_getGeneralRadius()); */
+/*   val = visu_gl_pairs_cylinder_getColorType(); */
 /*   switch (val) */
 /*     { */
-/*     case cylinder_user_color: */
+/*     case VISU_GL_PAIRS_CYLINDER_COLOR_USER: */
 /*       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioCylinderUser), TRUE); */
 /*       break; */
-/*     case cylinder_element_color: */
+/*     case VISU_GL_PAIRS_CYLINDER_COLOR_ELEMENT: */
 /*       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radioCylinderElement), TRUE); */
 /*       break; */
 /*     } */
 /* } */
 
-void gtkPairsCylinderSet_values(VisuPairData *data)
+/**
+ * visu_ui_pairs_cylinder_setValues:
+ * @data: information about a pair.
+ *
+ * Change the widget values with the given information. This change trigger
+ * no signals.
+ */
+void visu_ui_pairs_cylinder_setValues(VisuPairLink *data)
 {
-  float *radius;
-  float val;
-
-  radius = (float*)visu_pair_data_getProperty(data, "radius");
-  if (radius)
-    val = *radius;
-  else
-    val = cylinderGet_generalRadius();
-
   g_signal_handler_block(G_OBJECT(spinCylinderRadius), signalSpinCylinderRadiusId);
-  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius), val);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinCylinderRadius),
+                            visu_gl_pairs_cylinder_getRadius(data));
   g_signal_handler_unblock(G_OBJECT(spinCylinderRadius), signalSpinCylinderRadiusId);
 }
-
-gchar* gtkPairsCylinderGet_valuesAsLabel(VisuPairData *data)
+/**
+ * visu_ui_pairs_cylinder_getValues:
+ * @data: information about a pair
+ *
+ * Create an internationalised UTF-8 label that describes the
+ * information about a pair.
+ *
+ * Returns: (transfer full): a newly allocated string.
+ */
+gchar* visu_ui_pairs_cylinder_getValues(VisuPairLink *data)
 {
   gchar *str;
-  float *radius;
-  float val;
-
-  radius = (float*)visu_pair_data_getProperty(data, "radius");
-  if (radius)
-    val = *radius;
-  else
-    val = cylinderGet_generalRadius();
 
   /* a.u. is for arbitrary units. */
-  str = g_strdup_printf("%s %3.2f%s", _("cyl.:"), val, _("a.u."));
+  str = g_strdup_printf("%s %3.2f%s", _("cyl.:"),
+                        visu_gl_pairs_cylinder_getRadius(data), _("a.u."));
 
   return str;
 }
