@@ -47,42 +47,12 @@
 #include <gtk/gtk.h>
 #include <visu_pairs.h>
 
-/**
- * gtkPairsWireInit:
- *
- * This routine is used by V_Sim to initialise the Gtk part of
- * wire pair model. This should be called once on start-up.
- */
-void gtkPairsWireInit(void);
+void visu_ui_pairs_wire_init(void);
 
-/**
- * gtkPairsWireBuild_widgets:
- *
- * This routine create a container #GtkWidget that hold all widgets
- * necessary for handling wire pair model.
- *
- * Returns: a newly created #GtkWidget.
- */
-GtkWidget* gtkPairsWireBuild_widgets();
+GtkWidget* visu_ui_pairs_wire_initBuild();
 
-/**
- * gtkPairsWireSet_values:
- * @data: information about a pair.
- *
- * Change the widget values with the given information. This change trigger
- * no signals.
- */
-void gtkPairsWireSet_values(VisuPairData *data);
+void visu_ui_pairs_wire_setValues(VisuPairLink *data);
 
-/**
- * gtkPairsWireGet_valuesAsLabel:
- * @data: information about a pair
- *
- * Create an internationalised UTF-8 label that describes the
- * information about a pair.
- *
- * Returns: a newly allocated string.
- */
-gchar* gtkPairsWireGet_valuesAsLabel(VisuPairData *data);
+gchar* visu_ui_pairs_wire_getValues(VisuPairLink *data);
 
 #endif
