@@ -43,24 +43,20 @@
 */
 #include "panelConfig.h"
 
+#include <string.h>
+#include <sys/stat.h>
+
 #include <support.h>
-#include <visu_gtk.h>
-#include <visu_tools.h>
 #include <visu_object.h>
 #include <visu_basic.h>
-#include <visu_data.h>
 #include <visu_configFile.h>
-#include <gtk_renderingWindowWidget.h>
-#include <extraGtkFunctions/gtk_numericalEntryWidget.h>
-#include <extraGtkFunctions/gtk_toolPanelWidget.h>
-#include <coreTools/toolColor.h>
 #include <coreTools/toolConfigFile.h>
 
-#include <sys/stat.h>
-
 /**
  * SECTION: panelConfig
  * @short_description: The tab where miscellaneous options are setup.
+ *
+ * <para>Nothing special here.</para>
  */
 
 #define FLAG_PARAMETER_TABVIEW_CONFIG   "config_subPanelTabView"
@@ -75,32 +71,31 @@
 #define PARAMETER_CONFIG_SKIN_DEFAULT      "None"
 #define PARAMETER_CONFIG_REFRESH_DEFAULT   0
 #define PARAMETER_CONFIG_PERIOD_DEFAULT    250
-static int config_subPanelTabView;
+static gboolean config_subPanelTabView;
 static gchar *config_skin;
 static int config_refreshIsOn;
 static float config_refreshPeriod;
-static GtkWidget *comboUnit;
+static GtkWidget *comboUnit, *panelVBox;
 
 
 /* Private functions. */
-GtkWidget *createInteriorConfig();
+static GtkWidget *createInteriorConfig();
 static void setSkin(char* label);
-void setAutomaticRefresh(int bool);
-void setRefreshPeriod(float val);
 static gboolean automaticReload(gpointer data);
 
 /* This function details how to read the preferedNumberOfViews
    parameter. */
-static gboolean readConfigTabView(gchar **lines, int nbLines, int position,
-				  VisuData *dataObj, GError **error);
-static gboolean readConfigSkin(gchar **lines, int nbLines, int position,
-			       VisuData *dataObj, GError **error);
-static gboolean readConfigRefresh(gchar **lines, int nbLines, int position,
-				  VisuData *dataObj, GError **error);
-static gboolean readConfigPeriod(gchar **lines, int nbLines, int position,
-				 VisuData *dataObj, GError **error);
+static gboolean readConfigTabView(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				  VisuData *dataObj, VisuGlView *view, GError **error);
+static gboolean readConfigSkin(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+			       VisuData *dataObj, VisuGlView *view, GError **error);
+static gboolean readConfigRefresh(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				  VisuData *dataObj, VisuGlView *view, GError **error);
+static gboolean readConfigPeriod(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				 VisuData *dataObj, VisuGlView *view, GError **error);
 /* These functions write all the element list to export there associated resources. */
-static void exportParametersPanelConfig(GString *data, VisuData* dataObj);
+static void exportParametersPanelConfig(GString *data,
+                                        VisuData* dataObj, VisuGlView *view);
 static void onUnitChanged(GtkComboBox *combo, gpointer data);
 
 static void initPanelConfigGtkPart();
@@ -110,7 +105,7 @@ static char *defaultSkinPath, *userSkinPath;
 gboolean isPanelConfigInitialized;
 
 /* Specific widgets used in this panel. */
-static GtkWidget *visuConfigData;
+static VisuUiPanel *panelConfig;
 static GtkWidget *checkShowTab;
 static GtkWidget *checkRefreshAuto;
 static GtkWidget *checkStorePositions;
@@ -125,80 +120,93 @@ void entryRcFilesChanged(GtkEntry *entry, gpointer data);
 void directorySelectedForResources(GtkButton *button, gpointer user_data);
 void openRcFileSelector(GtkButton *button, gpointer data);
 static void onRefreshPeriodChanged(GtkSpinButton* button, gpointer data);
-void onDataReadySignal(GObject *obj, VisuData *dataObj, gpointer data);
+static void onDataFocused(GObject *obj, VisuData *dataObj, gpointer data);
 gboolean treePathClicked(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 void directoryRemoveFromResources(GtkButton *button, gpointer user_data);
-static void onConfigEnter(ToolPanel *toolPanel, gpointer data);
+static void onConfigEnter(VisuUiPanel *visu_ui_panel, gpointer data);
 
-ToolPanel* panelConfigInit()
+/**
+ * visu_ui_panel_config_init: (skip)
+ * @ui: a #VisuUiMain object.
+ *
+ * Should be used in the list declared in externalModules.h to be loaded by
+ * V_Sim on start-up. This routine will create the #VisuUiPanel where the configuration
+ * stuff can be done, such as the auto-reloading.
+ *
+ * Returns: a newly created #VisuUiPanel object.
+ */
+VisuUiPanel* visu_ui_panel_config_init(VisuUiMain *ui)
 {
   char *cl = _("Configure the interface");
   char *tl = _("Configuration");
-  VisuConfigFileEntry *resourceEntry;
 
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
-					  FLAG_PARAMETER_TABVIEW_CONFIG,
-					  DESC_PARAMETER_TABVIEW_CONFIG,
-					  1, readConfigTabView);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
-					  FLAG_PARAMETER_SKIN_CONFIG,
-					  DESC_PARAMETER_SKIN_CONFIG,
-					  1, readConfigSkin);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
-					  FLAG_PARAMETER_REFRESH_CONFIG,
-					  DESC_PARAMETER_REFRESH_CONFIG,
-					  1, readConfigRefresh);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_PARAMETER,
-					  FLAG_PARAMETER_PERIOD_CONFIG,
-					  DESC_PARAMETER_PERIOD_CONFIG,
-					  1, readConfigPeriod);
-  visu_configFile_addExportFunction(VISU_CONFIGFILE_PARAMETER,
-				   exportParametersPanelConfig);
+  visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
+                           FLAG_PARAMETER_TABVIEW_CONFIG,
+                           DESC_PARAMETER_TABVIEW_CONFIG,
+                           1, readConfigTabView);
+  visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
+                           FLAG_PARAMETER_SKIN_CONFIG,
+                           DESC_PARAMETER_SKIN_CONFIG,
+                           1, readConfigSkin);
+  visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
+                           FLAG_PARAMETER_REFRESH_CONFIG,
+                           DESC_PARAMETER_REFRESH_CONFIG,
+                           1, readConfigRefresh);
+  visu_config_file_addEntry(VISU_CONFIG_FILE_PARAMETER,
+                           FLAG_PARAMETER_PERIOD_CONFIG,
+                           DESC_PARAMETER_PERIOD_CONFIG,
+                           1, readConfigPeriod);
+  visu_config_file_addExportFunction(VISU_CONFIG_FILE_PARAMETER,
+                                    exportParametersPanelConfig);
 
+#if GTK_MAJOR_VERSION < 3
   defaultSkinPath = g_build_filename(visu_basic_getDataDir(), "v_sim.rc", NULL);
   userSkinPath    = g_build_filename(visu_basic_getLocalDir(), "v_sim.rc", NULL);
+#else
+  defaultSkinPath = g_build_filename(visu_basic_getDataDir(), "v_sim.css", NULL);
+  userSkinPath    = g_build_filename(visu_basic_getLocalDir(), "v_sim.css", NULL);
+#endif
   config_subPanelTabView = PARAMETER_CONFIG_TABVIEW_DEFAULT;
   config_refreshPeriod = -1;
   config_refreshIsOn = -1;
-  panelConfigSet_refreshPeriod((VisuRenderingWindow*)0, PARAMETER_CONFIG_PERIOD_DEFAULT);
-  panelConfigSet_automaticRefresh((VisuRenderingWindow*)0, PARAMETER_CONFIG_REFRESH_DEFAULT);
 
   /* Now that everything has a value, we create the panel. */
-  visuConfigData = toolPanelNew_withIconFromStock("Panel_configuration",
-						  cl, tl, GTK_STOCK_PREFERENCES);
-  if (!visuConfigData)
-    return (ToolPanel*)0;
+  panelConfig = VISU_UI_PANEL(visu_ui_panel_newWithIconFromStock("Panel_configuration",
+                                                                 cl, tl,
+                                                                 GTK_STOCK_PREFERENCES));
+  if (!panelConfig)
+    return (VisuUiPanel*)0;
 
   isPanelConfigInitialized = FALSE;
+  visu_ui_panel_config_setRefreshPeriod((VisuUiRenderingWindow*)0, PARAMETER_CONFIG_PERIOD_DEFAULT);
+  visu_ui_panel_config_setAutomaticRefresh((VisuUiRenderingWindow*)0, PARAMETER_CONFIG_REFRESH_DEFAULT);
 
   /* Set global callbacks. */
-  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
-		   G_CALLBACK(onDataReadySignal), (gpointer)0);
-  g_signal_connect(G_OBJECT(visuConfigData), "page-entered",
+  g_signal_connect(G_OBJECT(ui), "DataFocused",
+		   G_CALLBACK(onDataFocused), (gpointer)0);
+  g_signal_connect(G_OBJECT(panelConfig), "page-entered",
 		   G_CALLBACK(onConfigEnter), (gpointer)0);
 
-  return TOOL_PANEL(visuConfigData);
+  return panelConfig;
 }
 
 static void initPanelConfigGtkPart()
 {
-  GtkWidget *wd;
-
   if (isPanelConfigInitialized)
     return;
 
   DBG_fprintf(stderr, "Panel Config : creating the config panel on demand.\n");
   isPanelConfigInitialized = TRUE;
 
-  wd = createInteriorConfig();
-  gtk_container_add(GTK_CONTAINER(visuConfigData), wd);
+  panelVBox = createInteriorConfig();
+  gtk_container_add(GTK_CONTAINER(panelConfig), panelVBox);
 
   /* Force the callbacks to initialise the values. */
   checkShowTabToggled((GtkToggleButton*)0, (gpointer)0);
 }
 
 
-GtkWidget *createInteriorConfig()
+static GtkWidget *createInteriorConfig()
 {
   GtkWidget *vbox;
   GtkWidget *hbox;
@@ -226,6 +234,8 @@ GtkWidget *createInteriorConfig()
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRefreshAuto),
 			       (gboolean)config_refreshIsOn);
   gtk_box_pack_start(GTK_BOX(hbox), checkRefreshAuto, FALSE, FALSE, 0);
+  hbox = gtk_hbox_new(FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
   label = gtk_label_new(_(" ms"));
   gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
   spinRefresh = gtk_spin_button_new_with_range(10., 10000., 10.);
@@ -241,13 +251,10 @@ GtkWidget *createInteriorConfig()
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStorePositions),
 			       (gboolean)TRUE);
   gtk_box_pack_start(GTK_BOX(hbox), checkStorePositions, FALSE, FALSE, 0);
-  label = gtk_label_new(_("<span size=\"small\">(because I've a bad WM)</span>"));
-  gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-  gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
   checkRedCoord = gtk_check_button_new_with_mnemonic(_("Display _coordinates in reduce"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRedCoord),
-			       (gboolean)visu_rendering_window_getDisplayCoordinatesInReduce());
+			       (gboolean)visu_ui_rendering_window_class_getDisplayCoordinatesInReduce());
   gtk_box_pack_start(GTK_BOX(vbox), checkRedCoord, FALSE, FALSE, 3);
 
   hbox = gtk_hbox_new(FALSE, 0);
@@ -285,34 +292,34 @@ GtkWidget *createInteriorConfig()
 /*************/
 static void checkShowTabToggled(GtkToggleButton *button _U_, gpointer data _U_)
 {
-  panelConfigSet_tabView(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkShowTab)));
+  visu_ui_panel_config_setTabView(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkShowTab)));
 }
 static void checkRememberToggled(GtkToggleButton *button, gpointer data _U_)
 {
-  visu_uiMainClass_setRememberPosition(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
+  visu_ui_main_class_setRememberPosition(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
 }
-static void onConfigEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
+static void onConfigEnter(VisuUiPanel *visu_ui_panel _U_, gpointer data _U_)
 {
   if (!isPanelConfigInitialized)
     initPanelConfigGtkPart();
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkStorePositions),
-			       visu_uiMainClass_getRememberPosition());
+			       visu_ui_main_class_getRememberPosition());
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkRedCoord),
-			       visu_rendering_window_getDisplayCoordinatesInReduce());
+			       visu_ui_rendering_window_class_getDisplayCoordinatesInReduce());
 }
 static void checkRefreshToggled(GtkToggleButton *button, gpointer data _U_)
 {
-  panelConfigSet_automaticRefresh(visu_uiMainClass_getDefaultRendering(),
+  visu_ui_panel_config_setAutomaticRefresh(visu_ui_main_class_getDefaultRendering(),
 				  gtk_toggle_button_get_active(button));
 }
 static void checkRedCoordToggled(GtkToggleButton *button, gpointer data _U_)
 {
-  visu_rendering_window_setDisplayCoordinatesInReduce(gtk_toggle_button_get_active(button));
+  visu_ui_rendering_window_class_setDisplayCoordinatesInReduce(gtk_toggle_button_get_active(button));
 }
 static void onRefreshPeriodChanged(GtkSpinButton* button, gpointer data _U_)
 {
-  panelConfigSet_refreshPeriod(visu_uiMainClass_getDefaultRendering(),
+  visu_ui_panel_config_setRefreshPeriod(visu_ui_main_class_getDefaultRendering(),
 			       (float)gtk_spin_button_get_value(button));
 }
 void openRcFileSelector(GtkButton *button _U_, gpointer data _U_)
@@ -320,8 +327,13 @@ void openRcFileSelector(GtkButton *button _U_, gpointer data _U_)
 }
 static void setSkin(char* label)
 {
-  GtkSettings *settings;
   char *tmp;
+#if GTK_MAJOR_VERSION < 3
+  GtkSettings *settings;
+#else
+  GError *error;
+  GtkCssProvider *css;
+#endif
 
   if (!label || label[0] == '\0' || !strcmp(label, "None"))
     return;
@@ -342,12 +354,29 @@ static void setSkin(char* label)
 	      tmp, g_file_test(tmp, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR));
   if (!g_file_test(tmp, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
     return;
-  gtk_rc_parse(tmp);
 
+#if GTK_MAJOR_VERSION < 3
+  gtk_rc_parse(tmp);
   DBG_fprintf(stderr, "Panel Config: get the settings.\n");
   settings = gtk_settings_get_default ();
   gtk_rc_reparse_all_for_settings(settings, TRUE);
   DBG_fprintf(stderr,"Panel Config: applying RC file OK.\n");
+#else
+  css = gtk_css_provider_new();
+  error = (GError*)0;
+  gtk_css_provider_load_from_path(css, tmp, &error);
+  if (error)
+    {
+      g_warning("%s", error->message);
+      g_error_free(error);
+    }
+  DBG_fprintf(stderr, "Panel Config: CSS file loaded.\n");
+  gtk_style_context_add_provider_for_screen(gdk_screen_get_default(),
+                                            GTK_STYLE_PROVIDER(css),
+                                            GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+  g_object_unref(G_OBJECT(css));
+  gtk_style_context_reset_widgets(gdk_screen_get_default());
+#endif
 }
 void autoReloadAddTimeout(VisuData *data, guint time, gpointer user_data)
 {
@@ -383,23 +412,18 @@ static gboolean automaticReload(gpointer data)
 {
   struct stat statBuf;
   int res, iSet;
-  char *file;
+  const gchar *file;
   time_t modTime;
   int kind, nbKind;
-  gboolean reloadNeeded, ok;
-  VisuRenderingWindow *window;
+  gboolean reloadNeeded;
   VisuData *dataObj;
   time_t *lastReadTime;
-  GError *error;
 
-  DBG_fprintf(stderr, "Panel Config : automatic reload called.\n");
-  window = RENDERING_WINDOW(data);
-  g_return_val_if_fail(window, TRUE);
-
-  dataObj = visu_rendering_window_getVisuData(window);
+  DBG_fprintf(stderr, "Panel Config: automatic reload called.\n");
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(panelConfig));
   if (!dataObj)
     {
-      DBG_fprintf(stderr, "Panel Config : automatic reload aborted, no file available.\n");
+      DBG_fprintf(stderr, "Panel Config: automatic reload aborted, no file available.\n");
       return TRUE;
     }
   
@@ -407,7 +431,7 @@ static gboolean automaticReload(gpointer data)
   g_return_val_if_fail(lastReadTime, TRUE);
 
   reloadNeeded = FALSE;
-  nbKind = visu_rendering_getNFileTypes(visu_object_getRendering(VISU_INSTANCE));
+  nbKind = visu_rendering_getNFileTypes(visu_object_getRendering(VISU_OBJECT_INSTANCE));
   for (kind = 0; kind < nbKind; kind++)
     {
       file = visu_data_getFile(dataObj, kind, (ToolFileFormat**)0);
@@ -427,41 +451,27 @@ static gboolean automaticReload(gpointer data)
     }
   if (reloadNeeded)
     {
-      DBG_fprintf(stderr, "Panel Config : automatic reloading in progress...\n");
+      DBG_fprintf(stderr, "Panel Config: automatic reloading in progress...\n");
       iSet = visu_data_getISubset(dataObj);
       visu_data_freePopulation(dataObj);
-      error = (GError*)0;
-      ok = visu_basic_loadData(dataObj, (ToolFileFormat*)0, iSet, &error);
-      if (!ok)
-	{
-	  visuGtkRaise_warning(_("Automatic file reloading"), error->message,
-			       (GtkWindow*)0);
-	  g_error_free(error);
-	  visu_rendering_window_setData(window, (VisuData*)0);
-	}
-      else
-	{
-	  visu_rendering_window_setData(window, dataObj);
-	  visu_data_createAllNodes(dataObj);
-	}
-      visu_object_redraw((gpointer)0);
+      visu_ui_rendering_window_loadFile(VISU_UI_RENDERING_WINDOW(data), dataObj, iSet);
     }
   return TRUE;
 }
-void onDataReadySignal(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
+static void onDataFocused(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
 {
   struct stat statBuf;
   int res;
-  char *file;
+  const gchar *file;
   int kind, nbKind;
   time_t *lastReadTime;
 
   if (!dataObj)
     return;
 
-  DBG_fprintf(stderr, "Panel Config: caught the 'dataReadyForRendering' signal,"
+  DBG_fprintf(stderr, "Panel Config: caught the 'DataFocused' signal,"
 	      " set acces time for VisuData %p.\n", (gpointer)dataObj);
-  nbKind = visu_rendering_getNFileTypes(visu_object_getRendering(VISU_INSTANCE));
+  nbKind = visu_rendering_getNFileTypes(visu_object_getRendering(VISU_OBJECT_INSTANCE));
   lastReadTime = g_malloc(sizeof(time_t) * nbKind);
   for (kind = 0; kind < nbKind; kind++)
     {
@@ -481,7 +491,7 @@ void onDataReadySignal(GObject *obj _U_, VisuData *dataObj, gpointer data _U_)
 			 lastReadTime, g_free);
   if (config_refreshIsOn)
     autoReloadAddTimeout(dataObj, config_refreshPeriod,
-			 (gpointer)visu_uiMainClass_getDefaultRendering());
+			 (gpointer)visu_ui_main_class_getDefaultRendering());
 }
 static void onUnitChanged(GtkComboBox *combo, gpointer data _U_)
 {
@@ -493,21 +503,37 @@ static void onUnitChanged(GtkComboBox *combo, gpointer data _U_)
 /**********************************/
 /* Public method to change values */
 /**********************************/
-
-void panelConfigSet_tabView(gboolean viewed)
+/**
+ * visu_ui_panel_config_setTabView:
+ * @viewed: a boolean value.
+ *
+ * The note can show its tabs or not. Change this with that method.
+ */
+void visu_ui_panel_config_setTabView(gboolean viewed)
 {
   DBG_fprintf(stderr,"Panel Config : toggle tab view -> %d (previously %d)\n",
 	      (int)viewed, config_subPanelTabView);
   if (viewed == config_subPanelTabView)
     return;
 
-  toolPanelClassSet_headerVisibility(viewed);
+  visu_ui_panel_class_setHeaderVisibility(viewed);
   
   /* set the associated parameter. */
   config_subPanelTabView = viewed;
 }
-void panelConfigSet_automaticRefresh(VisuRenderingWindow *window, int bool)
+/**
+ * visu_ui_panel_config_setAutomaticRefresh:
+ * @window: the #VisuUiRenderingWindow to associated the auto refresh ;
+ * @bool: a boolean value.
+ *
+ * V_Sim can poll the rendered file at periodic intervals to check if the file
+ * has been modified. If true, the file is reloaded. Turn this functionality on or off
+ * with this method. See visu_ui_panel_config_setRefreshPeriod() to tune the period of the polling.
+ */
+void visu_ui_panel_config_setAutomaticRefresh(VisuUiRenderingWindow *window, gboolean bool)
 {
+  VisuData *dataObj;
+
   DBG_fprintf(stderr, "Panel Config : set refresh to %d (previously %d).\n",
 	      bool, config_refreshIsOn);
 
@@ -515,16 +541,25 @@ void panelConfigSet_automaticRefresh(VisuRenderingWindow *window, int bool)
     return;
 
   config_refreshIsOn = bool;
-  if (window && visu_rendering_window_getVisuData(window))
+
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(panelConfig));
+  if (dataObj)
     {
       if (bool)
-	autoReloadAddTimeout(visu_rendering_window_getVisuData(window),
-			     config_refreshPeriod, (gpointer)window);
+	autoReloadAddTimeout(dataObj, config_refreshPeriod, (gpointer)window);
       else
-	autoReloadRemoveTimeout(visu_rendering_window_getVisuData(window));
+	autoReloadRemoveTimeout(dataObj);
     }
 }
-void panelConfigSet_refreshPeriod(VisuRenderingWindow *window, float val)
+/**
+ * visu_ui_panel_config_setRefreshPeriod:
+ * @window: the #VisuUiRenderingWindow to associated the auto refresh ;
+ * @val: a floating point value in milliseconds.
+ *
+ * V_Sim can poll the rendered file at periodic intervals. Use this method to tune
+ * the period. See visu_ui_panel_config_setAutomaticRefresh() to enable this functionality.
+ */
+void visu_ui_panel_config_setRefreshPeriod(VisuUiRenderingWindow *window, float val)
 {
   VisuData *dataObj;
 
@@ -535,7 +570,7 @@ void panelConfigSet_refreshPeriod(VisuRenderingWindow *window, float val)
     return;
 
   config_refreshPeriod = val;
-  dataObj = (window)?visu_rendering_window_getVisuData(window):(VisuData*)0;
+  dataObj = visu_ui_panel_getData(VISU_UI_PANEL(panelConfig));
   if (dataObj && config_refreshIsOn)
     {
       DBG_fprintf(stderr, "Panel Config : stopping the callback of refresh "
@@ -544,7 +579,23 @@ void panelConfigSet_refreshPeriod(VisuRenderingWindow *window, float val)
       autoReloadAddTimeout(dataObj, config_refreshPeriod, (gpointer)window);
     }
 }
-
+/**
+ * visu_ui_panel_config_getArea:
+ *
+ * This routine can be used to extend the configure panel from plug-ins.
+ *
+ * Since: 3.7
+ *
+ * Returns: (transfer none): a #GtkBox containing elements of the
+ * configure panel.
+ **/
+GtkWidget* visu_ui_panel_config_getArea()
+{
+  if (!isPanelConfigInitialized)
+    initPanelConfigGtkPart();
+  
+  return panelVBox;
+}
 
 /********************/
 /* In/Out functions */
@@ -552,21 +603,23 @@ void panelConfigSet_refreshPeriod(VisuRenderingWindow *window, float val)
 
 /* This function details how to read the preferedNumberOfViews
    parameter. */
-static gboolean readConfigTabView(gchar **lines, int nbLines, int position,
-				  VisuData *dataObj _U_, GError **error)
+static gboolean readConfigTabView(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				  VisuData *dataObj _U_, VisuGlView *view _U_,
+                                  GError **error)
 {
   gboolean viewed;
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readBoolean(lines[0], position, &viewed, 1, error))
+  if (!tool_config_file_readBoolean(lines[0], position, &viewed, 1, error))
     return FALSE;
-  panelConfigSet_tabView(viewed);
+  visu_ui_panel_config_setTabView(viewed);
   
   return TRUE;
 }
-static gboolean readConfigSkin(gchar **lines, int nbLines, int position,
-			       VisuData *dataObj _U_, GError **error)
+static gboolean readConfigSkin(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+			       VisuData *dataObj _U_, VisuGlView *view _U_,
+                               GError **error)
 {
   g_return_val_if_fail(nbLines == 1, FALSE);
 
@@ -574,7 +627,7 @@ static gboolean readConfigSkin(gchar **lines, int nbLines, int position,
 
   if (!lines[0][0])
     {
-      *error = g_error_new(TOOL_CONFIGFILE_ERROR, TOOL_CONFIGFILE_ERROR_VALUE,
+      *error = g_error_new(TOOL_CONFIG_FILE_ERROR, TOOL_CONFIG_FILE_ERROR_VALUE,
 			   _("Parse error at line %d: 1 string value must appear"
 			     " after the %s markup.\n"), position,
 			   FLAG_PARAMETER_SKIN_CONFIG);
@@ -588,37 +641,40 @@ static gboolean readConfigSkin(gchar **lines, int nbLines, int position,
 
   return TRUE;
 }
-static gboolean readConfigRefresh(gchar **lines, int nbLines, int position,
-				  VisuData *dataObj _U_, GError **error)
+static gboolean readConfigRefresh(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				  VisuData *dataObj _U_, VisuGlView *view _U_,
+                                  GError **error)
 {
   gboolean bool;
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readBoolean(lines[0], position, &bool, 1, error))
+  if (!tool_config_file_readBoolean(lines[0], position, &bool, 1, error))
     return FALSE;
-  panelConfigSet_automaticRefresh(visu_uiMainClass_getDefaultRendering(), bool);
+  visu_ui_panel_config_setAutomaticRefresh(visu_ui_main_class_getDefaultRendering(), bool);
 
   return TRUE;
 }
-static gboolean readConfigPeriod(gchar **lines, int nbLines, int position,
-				 VisuData *dataObj _U_, GError **error)
+static gboolean readConfigPeriod(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				 VisuData *dataObj _U_, VisuGlView *view _U_,
+                                 GError **error)
 {
   float val;
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readFloat(lines[0], position, &val, 1, error))
+  if (!tool_config_file_readFloat(lines[0], position, &val, 1, error))
     return FALSE;
   config_refreshPeriod = val;
-  panelConfigSet_refreshPeriod(visu_uiMainClass_getDefaultRendering(),
+  visu_ui_panel_config_setRefreshPeriod(visu_ui_main_class_getDefaultRendering(),
 			       config_refreshPeriod);
 
   return TRUE;
 }
 
 /* These functions write all the element list to export there associated resources. */
-static void exportParametersPanelConfig(GString *data, VisuData *dataObj _U_)
+static void exportParametersPanelConfig(GString *data,
+                                        VisuData *dataObj _U_, VisuGlView *view _U_)
 {
   g_string_append_printf(data, "# %s\n", DESC_PARAMETER_TABVIEW_CONFIG);
   g_string_append_printf(data, "%s[gtk]: %d\n\n", FLAG_PARAMETER_TABVIEW_CONFIG,
