@@ -79,14 +79,46 @@
  * <para>If the OpenGL representation of one element is not dependent
  * of its position, it is recommended to use the OpenGL list
  * associated to each #VisuElement that can be accessed by a call to
- * visu_element_getIdentifierMaterial().</para>
+ * visu_element_getMaterialId().</para>
+ */
+
+/**
+ * VisuElement:
+ *
+ * Structure to stores #VisuElement objects.
+ */
+
+/**
+ * _VisuElement:
+ * @parent: the parent.
+ * @name: Name of the key used in the hashtable to find
+ *   this element. The int variable is the number
+ *   of this type.
+ * @typeNumber: An integer unique for each VisuElement, it is
+ *   used as a name for the opengl material associated
+ *   with it.
+ * @rgb: main color of the element  in [r, g, b, a] format.
+ * @material: lighting effects for material in [amb, dif, shi, spe,
+ * emi] format.
+ * @glMaterialId: the identifier for the material of this element.
+ * @materialIsUpToDate: A flag that is TRUE when the OpenGL list of
+ *   the  material is up to date.
+ * @rendered: A flag to store if all nodes of this element are rendered or not.
+ *   Its default value is TRUE.
+ * @sensitiveToPlanes: a flag to say if nodes of this element are sensitive
+ *   to the masking effect of planes (default is TRUE).
+ * @physical: TRUE if the element is a physical one.
+ * @dispose_has_run: internal.
+ *
+ * Structure to store the description of an element.
  */
 
 enum {
   ELEMENT_NEW_SIGNAL,
-  ELEMENT_RENDERED_CHANGED_SIGNAL,
+  ELEMENT_VISIBILITY_CHANGED_SIGNAL,
   ELEMENT_MATERIAL_CHANGED_SIGNAL,
-  ELEMENT_PLANE_CHANGED_SIGNAL,
+  ELEMENT_RENDERING_CHANGED_SIGNAL,
+  ELEMENT_VISU_PLANE_CHANGED_SIGNAL,
   LAST_SIGNAL
 };
 
@@ -94,12 +126,8 @@ struct _VisuElementClass
 {
   GObjectClass parent;
 
-  int identifierMaterials;
-  guint idEle;
-
   /* This hashtable contains a list of all different
-     elements loaded in visu. ntype is _not_ the number of items
-     in this hashtable. */
+     elements loaded in visu. */
   GHashTable *allElements_table;
   GList *allElements_list;
 
@@ -119,20 +147,22 @@ struct _VisuElementClass
 /* These functions detail how to read the RGB resource and
    the material resource introduced by this part.
    These routines are obsolete but kept for backward compatibility. */
-static gboolean readMaterial(gchar **lines, int nbLines, int position,
-			     VisuData *dataObj, GError **error);
-static gboolean readRendered(gchar **lines, int nbLines, int position,
-			     VisuData *dataObj, GError **error);
+static gboolean readMaterial(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+			     VisuData *dataObj, VisuGlView *view, GError **error);
+static gboolean readRendered(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+			     VisuData *dataObj, VisuGlView *view, GError **error);
 
 /* Read routines for the config file. */
-static gboolean readElementColor(gchar **lines, int nbLines, int position,
-				 VisuData *dataObj, GError **error);
-static gboolean readElementProperties(gchar **lines, int nbLines, int position,
-				      VisuData *dataObj, GError **error);
+static gboolean readElementColor(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				 VisuData *dataObj, VisuGlView *view, GError **error);
+static gboolean readElementProperties(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				      VisuData *dataObj, VisuGlView *view,
+                                      GError **error);
 
 
 /* These functions write all the element list to export there associated resources. */
-static void exportResourcesRenderingBase(GString *data, VisuData *dataObj);
+static void exportResourcesRenderingBase(GString *data,
+                                         VisuData *dataObj, VisuGlView *view);
 static void visu_element_dispose(GObject* obj);
 static void visu_element_finalize(GObject* obj);
 
@@ -148,7 +178,7 @@ static void visu_element_class_init(VisuElementClass *klass)
   DBG_fprintf(stderr, "Visu Element: creating the class of the object.\n");
   DBG_fprintf(stderr, "                - adding new signals ;\n");
   /**
-   * VisuElement::ElementRenderedChanged:
+   * VisuElement::ElementVisibilityChanged:
    * @element: the object which emit the signal ;
    *
    * Gets emitted when one of the rendered #VisuElement is made
@@ -156,8 +186,8 @@ static void visu_element_class_init(VisuElementClass *klass)
    *
    * Since: 3.6
    */
-  visu_element_signals[ELEMENT_RENDERED_CHANGED_SIGNAL] =
-    g_signal_new("ElementRenderedChanged",
+  visu_element_signals[ELEMENT_VISIBILITY_CHANGED_SIGNAL] =
+    g_signal_new("ElementVisibilityChanged",
                  G_TYPE_FROM_CLASS(klass),
                  G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
                  0, NULL, NULL, g_cclosure_marshal_VOID__VOID,
@@ -179,6 +209,24 @@ static void visu_element_class_init(VisuElementClass *klass)
                  0, NULL, NULL, g_cclosure_marshal_VOID__VOID,
                  G_TYPE_NONE, 0);
 
+  /**
+   * VisuElement::ElementRenderingChanged:
+   * @element: the object which emit the signal ;
+   *
+   * Gets emitted when the rendering characteristics of an element are
+   * changed, like their shape or specific colour. For a signal on
+   * generic colours (like the element colour), listen to
+   * VisuElement::ElementMaterialChanged signal instead.
+   *
+   * Since: 3.7
+   */
+  visu_element_signals[ELEMENT_RENDERING_CHANGED_SIGNAL] =
+    g_signal_new("ElementRenderingChanged",
+                 G_TYPE_FROM_CLASS(klass),
+                 G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
+                 0, NULL, NULL, g_cclosure_marshal_VOID__VOID,
+                 G_TYPE_NONE, 0);
+
   /**
    * VisuElement::ElementPlaneChanged:
    * @element: the object which emit the signal ;
@@ -187,7 +235,7 @@ static void visu_element_class_init(VisuElementClass *klass)
    *
    * Since: 3.6
    */
-  visu_element_signals[ELEMENT_PLANE_CHANGED_SIGNAL] =
+  visu_element_signals[ELEMENT_VISU_PLANE_CHANGED_SIGNAL] =
     g_signal_new("ElementPlaneChanged",
                  G_TYPE_FROM_CLASS(klass),
                  G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE,
@@ -222,35 +270,33 @@ static void visu_element_class_init(VisuElementClass *klass)
 
   /* Create a VisuModule to registered the new resources as
      rgb and material. */
-  oldEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
+  oldEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_RESOURCE,
 				     "material",
 				     "Obsolete entry for element_color",
 				     1, readMaterial);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
+  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_RESOURCE,
 					  FLAG_ELEMENT_COLOR,
 					  DESC_ELEMENT_COLOR,
 					  1, readElementColor);
-  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
-  visu_configFile_entry_setReplace(resourceEntry, oldEntry);
-  oldEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
+  visu_config_file_entry_setVersion(resourceEntry, 3.4f);
+  visu_config_file_entry_setReplace(resourceEntry, oldEntry);
+  oldEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_RESOURCE,
 				     "element_is_rendered",
 				     "Obsolete entry included in element_properties",
 				     1, readRendered);
-  visu_configFile_entry_setVersion(resourceEntry, 3.1f);
-  resourceEntry = visu_configFile_addEntry(VISU_CONFIGFILE_RESOURCE,
+  visu_config_file_entry_setVersion(resourceEntry, 3.1f);
+  resourceEntry = visu_config_file_addEntry(VISU_CONFIG_FILE_RESOURCE,
 					  FLAG_ELEMENT_PROPERTIES,
 					  DESC_ELEMENT_PROPERTIES,
 					  1, readElementProperties);
-  visu_configFile_entry_setVersion(resourceEntry, 3.4f);
-  visu_configFile_entry_setReplace(resourceEntry, oldEntry);
-  visu_configFile_addExportFunction(VISU_CONFIGFILE_RESOURCE,
+  visu_config_file_entry_setVersion(resourceEntry, 3.4f);
+  visu_config_file_entry_setReplace(resourceEntry, oldEntry);
+  visu_config_file_addExportFunction(VISU_CONFIG_FILE_RESOURCE,
 				   exportResourcesRenderingBase);
 
 
   /* Get an OpenGL identifier to store all the materials. */
-  klass->identifierMaterials = visu_openGL_objectList_new(VISU_ELEMENT_MAX_NUMBER);
   klass->flagCreateNodesAfterMaterialChange = 0;
-  klass->idEle = 0;
 
   my_class = klass;
 }
@@ -263,7 +309,10 @@ static void visu_element_init(VisuElement *ele)
 	      (gpointer)ele);
   ele->materialIsUpToDate       = FALSE;
   ele->rendered                 = TRUE;
-  ele->sensitiveToMaskingPlanes = TRUE;
+  ele->sensitiveToPlanes = TRUE;
+  ele->physical                 = TRUE;
+
+  ele->glMaterialId = visu_gl_objectlist_new(1);
 
   for (i = 0; i < 4; i++)
     ele->rgb[i] = 1.;
@@ -299,6 +348,7 @@ static void visu_element_finalize(GObject* obj)
   g_free(ele->name);
   g_hash_table_steal(klass->allElements_table, ele);
   klass->allElements_list = g_list_remove(klass->allElements_list, ele);
+  glDeleteLists(ele->glMaterialId, 1);
 
   /* Chain up to the parent class */
   DBG_fprintf(stderr, "Visu Element: chain to parent.\n");
@@ -321,30 +371,22 @@ VisuElement *visu_element_new(const char *key)
   VisuElement *ele;
 
   if (!my_class)
-    g_type_class_ref(VISU_ELEMENT_TYPE);
+    g_type_class_ref(VISU_TYPE_ELEMENT);
 
-  ele = g_hash_table_lookup(my_class->allElements_table, (gpointer)key);
+  ele = visu_element_lookup(key);
   if (ele)
     {
       g_warning("Element '%s' already exists.", key);
       return ele;
     }
 
-  ele = VISU_ELEMENT(g_object_new(VISU_ELEMENT_TYPE, NULL));
-  my_class->idEle += 1;
-  if (my_class->idEle == VISU_ELEMENT_MAX_NUMBER)
-    {
-      g_error("The system requires more than %d elements. This value is"
-              " set at compilation time with the variable VISU_ELEMENT_MAX_NUMBER. If you"
-              " need more, ask the maintainer to raise this value.\n", VISU_ELEMENT_MAX_NUMBER);
-    }
-  ele->name       = g_strdup(key);
-  ele->typeNumber = my_class->idEle;
+  ele = VISU_ELEMENT(g_object_new(VISU_TYPE_ELEMENT, NULL));
+  ele->name       = g_strdup((key[0] == '%')?key + 1:key);
+  ele->physical   = (key[0] != '%') && strcmp(key, "g") && strcmp(key, "G");
   g_hash_table_insert(my_class->allElements_table,
                       (gpointer)ele->name, (gpointer)ele);
   my_class->allElements_list = g_list_append(my_class->allElements_list, (gpointer)ele);
 
-
   DBG_fprintf(stderr, "Visu Elements: create a new VisuElement '%s' -> %p.\n",
 	      key, (gpointer)ele);  
   g_signal_emit(G_OBJECT(ele), visu_element_signals[ELEMENT_NEW_SIGNAL], 0, NULL);
@@ -365,7 +407,7 @@ VisuElement *visu_element_new(const char *key)
 const GList *visu_element_getAllElements(void)
 {
   if (!my_class)
-    g_type_class_ref(VISU_ELEMENT_TYPE);
+    g_type_class_ref(VISU_TYPE_ELEMENT);
 
   return my_class->allElements_list;
 }
@@ -385,15 +427,17 @@ VisuElement *visu_element_retrieveFromName(const gchar *name, gboolean *nw)
 {
   VisuElement *ele;
 
-  DBG_fprintf(stderr, "Visu Element: retrieve '%s'.\n", name);
-
   if (!my_class)
-    g_type_class_ref(VISU_ELEMENT_TYPE);
+    g_type_class_ref(VISU_TYPE_ELEMENT);
+
+  DBG_fprintf(stderr, "Visu Element: retrieve '%s' (%d).\n", name,
+              g_hash_table_size(my_class->allElements_table));
 
   if (nw)
     *nw = FALSE;
 
-  ele = g_hash_table_lookup(my_class->allElements_table, (gpointer)name);
+  ele = g_hash_table_lookup(my_class->allElements_table,
+                            (name[0] == '%')?name + 1:name);
   if (ele)
     return ele;
 
@@ -412,17 +456,52 @@ VisuElement *visu_element_retrieveFromName(const gchar *name, gboolean *nw)
  *
  * Since: 3.6
  *
- * Returns: the found #VisuElement or NULL.
+ * Returns: (transfer none): the found #VisuElement or NULL.
  */
 VisuElement *visu_element_lookup(const gchar *name)
 {
   if (!my_class)
-    g_type_class_ref(VISU_ELEMENT_TYPE);
+    g_type_class_ref(VISU_TYPE_ELEMENT);
 
-  return g_hash_table_lookup(my_class->allElements_table, (gpointer)name);
+  DBG_fprintf(stderr, "Visu Element: lookup '%s' (%d).\n",
+              name, g_hash_table_size(my_class->allElements_table));
+  return g_hash_table_lookup(my_class->allElements_table,
+                             (name[0] == '%')?name + 1:name);
 }
 
+/**
+ * visu_element_getName:
+ * @ele: a #VisuElement object.
+ *
+ * This routines returns the name of the given @ele.
+ *
+ * Since: 3.7
+ *
+ * Returns: a string owned by V_Sim.
+ */
+const gchar* visu_element_getName(const VisuElement *ele)
+{
+  g_return_val_if_fail(VISU_IS_ELEMENT_TYPE(ele), (const gchar*)0);
 
+  return ele->name;
+}
+/**
+ * visu_element_getPhysical:
+ * @ele: a #VisuElement object.
+ *
+ * This routine gets if @ele is physical or not. A not physical
+ * element can be used for instance to represent specific points...
+ *
+ * Since: 3.7
+ *
+ * Returns: TRUE if @ele is indeed physical.
+ */
+gboolean visu_element_getPhysical(VisuElement *ele)
+{
+  g_return_val_if_fail(VISU_IS_ELEMENT_TYPE(ele), FALSE);
+
+  return ele->physical;
+}
 /**
  * visu_element_setAllColorValues:
  * @ele: the element of which the color must be changed ;
@@ -432,8 +511,7 @@ VisuElement *visu_element_lookup(const gchar *name)
  * This method is used to set all the values that define the color
  * and the lighting of the given element.
  *
- * Returns: > 0 if visu_data_createNodes() should be called and then
- *          redraw is need if the value is not null.
+ * Returns: > 0 if values for @ele have changed.
  */
 gint visu_element_setAllColorValues(VisuElement* ele, float rgb[4], float material[5])
 {
@@ -476,8 +554,7 @@ gint visu_element_setAllColorValues(VisuElement* ele, float rgb[4], float materi
  *
  * It saves the values of rgb in the specified VisuElement.
  *
- * Returns: > 0 if visu_data_createNodes() should be called and then
- *          redraw is need if the value is not null.
+ * Returns: > 0 if values for @ele have changed.
  */
 gint visu_element_setAllRGBValues(VisuElement* ele, float rgb[4])
 {
@@ -523,8 +600,7 @@ gint visu_element_setAllRGBValues(VisuElement* ele, float rgb[4])
  * It saves the specific value of rgb (0 for red, 1 for green and 2
  * for bluein the specified VisuElement.
  *
- * Returns: > 0 if visu_data_createNodes() should be called and then
- *          redraw is need if the value is not null.
+ * Returns: > 0 if values for @ele have changed.
  */
 gint visu_element_setRGBValue(VisuElement* ele, int rgb, float value)
 {
@@ -555,8 +631,7 @@ gint visu_element_setRGBValue(VisuElement* ele, int rgb, float value)
  *
  * It saves the values of material in the specified VisuElement.
  *
- * Returns: > 0 if visu_data_createNodes() should be called and then
- *          redraw is need if the value is not null.
+ * Returns: > 0 if values for @ele have changed.
  */
 gint visu_element_setAllMaterialValues(VisuElement* ele, float material[5])
 {
@@ -591,8 +666,7 @@ gint visu_element_setAllMaterialValues(VisuElement* ele, float material[5])
  * It saves the specific value of material (use the enum as the parameter
  * material) in the specified VisuElement.
  *
- * Returns: > 0 if visu_data_createNodes() should be called and then
- *          redraw is need if the value is not null.
+ * Returns: > 0 if values for @ele have changed.
  */
 gboolean visu_element_setMaterialValue(VisuElement* ele, int material, float value)
 {
@@ -621,31 +695,30 @@ gboolean visu_element_setMaterialValue(VisuElement* ele, int material, float val
  * @element: a #VisuElement object ;
  * @status: TRUE or FALSE.
  *
- * This method sets the private attribute 'sensitiveToMaskingPlanes' to TRUE or FALSE
+ * This method sets the private attribute 'sensitiveToPlanes' to TRUE or FALSE
  * for the specified #visuElement. If TRUE, all the nodes of that #VisuElement
  * are not sensitive to the masking property of planes.
  *
- * Returns: 1 if the calling method should call visu_data_createNodes() for the given
- *          #VisuElement and then should add visu_object_redraw() to the Gloop.
+ * Returns: TRUE if values for @ele have changed.
  */
 gboolean visu_element_setSensitiveToPlanes(VisuElement *element, gboolean status)
 {
   g_return_val_if_fail(element, FALSE);
 
-  DBG_fprintf(stderr, "Visu Element: '%s' set sensitiveToMaskingPlanes %d\n",
-	      element->name, element->sensitiveToMaskingPlanes);
+  DBG_fprintf(stderr, "Visu Element: '%s' set sensitiveToPlanes %d\n",
+	      element->name, element->sensitiveToPlanes);
 
-  if (element->sensitiveToMaskingPlanes == status)
+  if (element->sensitiveToPlanes == status)
     return FALSE;
 
+  element->sensitiveToPlanes = status;
   DBG_fprintf(stderr, " -> %d\n", status);
 
   DBG_fprintf(stderr, "Visu Element: %p(%s) emit the 'ElementPlaneChanged'.\n",
               (gpointer)element, element->name);
-  g_signal_emit(element, visu_element_signals[ELEMENT_PLANE_CHANGED_SIGNAL],
+  g_signal_emit(element, visu_element_signals[ELEMENT_VISU_PLANE_CHANGED_SIGNAL],
                 0, NULL);
 
-  element->sensitiveToMaskingPlanes = status;
   return TRUE;
 }
 
@@ -662,14 +735,14 @@ gboolean visu_element_getSensitiveToPlanes(VisuElement *element)
 {
   g_return_val_if_fail(element, TRUE);
   
-  return element->sensitiveToMaskingPlanes;
+  return element->sensitiveToPlanes;
 }
 
 /**
  * visu_element_createMaterial:
  * @ele: a pointer to a valid %VisuElement.
  *
- * Create a list whose number is defined by #identifierMaterials + @ele->typeNumber
+ * Create a list whose number is defined by @ele->glMaterialId
  * that stores the definition of light and color for this #VisuElement. The previous
  * OpenGL object list with the same identifier is deleted.
  */
@@ -677,36 +750,34 @@ void visu_element_createMaterial(VisuElement *ele)
 {
   g_return_if_fail(ele);
 
-  DBG_fprintf(stderr, "Visu Element: create material for %s (ele id %d - OpenGL id %d)\n",
-              ele->name, ele->typeNumber,
-              VISU_ELEMENT_GET_CLASS(ele)->identifierMaterials + ele->typeNumber);
+  DBG_fprintf(stderr, "Visu Element: create material for %s (OpenGL id %d)\n",
+              ele->name, ele->glMaterialId);
 /*   fprintf(stderr, "%f %f %f - %f %f %f %f %f\n", ele->rgb[0], ele->rgb[1], ele->rgb[2], ele->material[0], ele->material[1], ele->material[2], ele->material[3], ele->material[4]); */
 
-  glDeleteLists(VISU_ELEMENT_GET_CLASS(ele)->identifierMaterials + ele->typeNumber, 1);
-  glNewList(VISU_ELEMENT_GET_CLASS(ele)->identifierMaterials + ele->typeNumber, GL_COMPILE);
-  glColor4fv(ele->rgb);
-  openGLSet_color(ele->material, ele->rgb);
+  glDeleteLists(ele->glMaterialId, 1);
+  glNewList(ele->glMaterialId, GL_COMPILE);
+  visu_gl_setColor(ele->material, ele->rgb);
   glEndList();
   ele->materialIsUpToDate = TRUE;
 }
 
 /**
- * visu_element_getIdentifierMaterial:
+ * visu_element_getMaterialId:
  * @ele: an element.
  *
  * This method is useful for the rendering method to get the
  * OpenGl identifier of the material of the specified element.
  *
- * Returns: the OpenGL identifier of the specified VisuElement.
+ * Returns: the OpenGL identifier of the specified #VisuElement.
  */
-int visu_element_getIdentifierMaterial(VisuElement *ele)
+int visu_element_getMaterialId(VisuElement *ele)
 {
   if (!ele)
     return 0;
 /*   if (!ele->materialIsUpToDate) */
 /*     visu_element_createMaterial(ele); */
 
-  return VISU_ELEMENT_GET_CLASS(ele)->identifierMaterials + ele->typeNumber;
+  return ele->glMaterialId;
 }
 
 /**
@@ -718,8 +789,7 @@ int visu_element_getIdentifierMaterial(VisuElement *ele)
  * for the specified #visuElement. If FALSE, all the nodes of that #VisuElement
  * are not included in the nodes OpenGL list.
  *
- * Returns: 1 if the calling method should call visu_data_createNodes() for the given
- *          #VisuElement and then should emit the 'OpenGLAskForReDraw' signal.
+ * Returns: TRUE if values for @ele have changed.
  */
 
 gboolean visu_element_setRendered(VisuElement *element, gboolean rendered)
@@ -730,9 +800,9 @@ gboolean visu_element_setRendered(VisuElement *element, gboolean rendered)
     return FALSE;
 
   element->rendered = rendered;
-  DBG_fprintf(stderr, "Visu Element: %p(%s) emit the 'ElementRenderedChanged'.\n",
+  DBG_fprintf(stderr, "Visu Element: %p(%s) emit the 'ElementVisibilityChanged'.\n",
               (gpointer)element, element->name);
-  g_signal_emit(element, visu_element_signals[ELEMENT_RENDERED_CHANGED_SIGNAL],
+  g_signal_emit(element, visu_element_signals[ELEMENT_VISIBILITY_CHANGED_SIGNAL],
 		0, NULL);
   return TRUE;
 }
@@ -765,7 +835,7 @@ gboolean visu_element_getRendered(VisuElement *element)
 void visu_element_setUpdateNodesOnMaterialChange(void)
 {
   if (!my_class)
-    g_type_class_ref(VISU_ELEMENT_TYPE);
+    g_type_class_ref(VISU_TYPE_ELEMENT);
 
   my_class->flagCreateNodesAfterMaterialChange += 1;
   DBG_fprintf(stderr, "Visu Element : set flagCreateNodesAfterMaterialChange to %d.\n",
@@ -782,7 +852,7 @@ void visu_element_setUpdateNodesOnMaterialChange(void)
 void visu_element_unsetUpdateNodesOnMaterialChange(void)
 {
   if (!my_class)
-    g_type_class_ref(VISU_ELEMENT_TYPE);
+    g_type_class_ref(VISU_TYPE_ELEMENT);
 
   my_class->flagCreateNodesAfterMaterialChange -= 1;
   if (my_class->flagCreateNodesAfterMaterialChange < 0)
@@ -797,13 +867,13 @@ void visu_element_unsetUpdateNodesOnMaterialChange(void)
  * Retrieve if one the #VisuElement is sensitive to the material
  * values. See visu_element_setUpdateNodesOnMaterialChange().
  *
- * Returns: TRUE if visu_data_createNodes() should be called when the
+ * Returns: TRUE if a #VisuGlExtNodes object should rebuild its nodes when the
  * material values are changed.
  */
 gboolean visu_element_getUpdateNodesOnMaterialChange(void)
 {
   if (!my_class)
-    g_type_class_ref(VISU_ELEMENT_TYPE);
+    g_type_class_ref(VISU_TYPE_ELEMENT);
 
   return (my_class->flagCreateNodesAfterMaterialChange > 0);
 }
@@ -811,15 +881,16 @@ gboolean visu_element_getUpdateNodesOnMaterialChange(void)
 /******************/
 /* Resources part */
 /******************/
-static gboolean readElementColor(gchar **lines, int nbLines, int position,
-				 VisuData *dataObj _U_, GError **error)
+static gboolean readElementColor(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+				 VisuData *dataObj _U_, VisuGlView *view _U_,
+                                 GError **error)
 {
   VisuElement* ele;
   float all[9];
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readFloatWithElement(lines[0], position, all, 9, &ele, error))
+  if (!tool_config_file_readFloatWithElement(lines[0], position, all, 9, &ele, error))
     return FALSE;
   ele->rgb[0] = CLAMP(all[0], 0., 1.);
   ele->rgb[1] = CLAMP(all[1], 0., 1.);
@@ -834,15 +905,16 @@ static gboolean readElementColor(gchar **lines, int nbLines, int position,
   
   return TRUE;
 }
-static gboolean readElementProperties(gchar **lines, int nbLines, int position,
-				 VisuData *dataObj _U_, GError **error)
+static gboolean readElementProperties(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+                                      VisuData *dataObj _U_, VisuGlView *view _U_,
+                                      GError **error)
 {
   VisuElement* ele;
   float values[2];
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readFloatWithElement(lines[0], position, values, 2, &ele, error))
+  if (!tool_config_file_readFloatWithElement(lines[0], position, values, 2, &ele, error))
     return FALSE;
   visu_element_setRendered(ele, (gboolean)values[0]);
   visu_element_setSensitiveToPlanes(ele, (gboolean)values[1]);
@@ -850,20 +922,20 @@ static gboolean readElementProperties(gchar **lines, int nbLines, int position,
   return TRUE;
 }
 
-static gboolean readMaterial(gchar **lines, int nbLines, int position,
-			     VisuData *dataObj, GError **error)
+static gboolean readMaterial(VisuConfigFileEntry *entry, gchar **lines, int nbLines, int position,
+			     VisuData *dataObj, VisuGlView *view, GError **error)
 {
-  return readElementColor(lines, nbLines, position, dataObj, error);
+  return readElementColor(entry, lines, nbLines, position, dataObj, view, error);
 }
-static gboolean readRendered(gchar **lines, int nbLines, int position,
-			     VisuData *dataObj _U_, GError **error)
+static gboolean readRendered(VisuConfigFileEntry *entry _U_, gchar **lines, int nbLines, int position,
+			     VisuData *dataObj _U_, VisuGlView *view _U_, GError **error)
 {
   VisuElement* ele;
   float value;
 
   g_return_val_if_fail(nbLines == 1, FALSE);
 
-  if (!tool_configFile_readFloatWithElement(lines[0], position, &value, 1, &ele, error))
+  if (!tool_config_file_readFloatWithElement(lines[0], position, &value, 1, &ele, error))
     return FALSE;
   visu_element_setRendered(ele, (gboolean)value);
   
@@ -871,54 +943,42 @@ static gboolean readRendered(gchar **lines, int nbLines, int position,
 }
 
 /* These functions read all the element list to export there associated resources. */
-static void exportResourcesRenderingBase(GString *data, VisuData *dataObj)
+static void exportResourcesRenderingBase(GString *data,
+                                         VisuData *dataObj, VisuGlView *view _U_)
 {
   GList *pos, *eleList;
-  unsigned int i;
+  VisuNodeArrayIter iter;
 
-  g_string_append_printf(data, "# %s\n", DESC_ELEMENT_COLOR);
+  visu_config_file_exportComment(data, DESC_ELEMENT_COLOR);
   /* We create a list of elements, or get the whole list. */
-  eleList = (GList*)0;
   if (dataObj)
     {
-      for (i = 0; i < dataObj->ntype; i++)
-	eleList = g_list_prepend(eleList, (gpointer)dataObj->fromIntToVisuElement[i]);
-      pos = eleList;
+      eleList = (GList*)0;
+      visu_node_array_iterNew(VISU_NODE_ARRAY(dataObj), &iter);
+      for (visu_node_array_iterStart(VISU_NODE_ARRAY(dataObj), &iter); iter.element;
+           visu_node_array_iterNextElement(VISU_NODE_ARRAY(dataObj), &iter))
+        eleList = g_list_prepend(eleList, (gpointer)iter.element);
     }
   else
-    pos = (GList*)visu_element_getAllElements();
-  while(pos)
-    {
-      g_string_append_printf(data, "%s:\n", FLAG_ELEMENT_COLOR);
-      g_string_append_printf(data, "    %s %4.3f %4.3f %4.3f %4.3f"
-			     "   %4.2f %4.2f %4.2f %4.2f %4.2f\n",
-			     ((VisuElement*)pos->data)->name,
-			     ((VisuElement*)pos->data)->rgb[0],
-			     ((VisuElement*)pos->data)->rgb[1],
-			     ((VisuElement*)pos->data)->rgb[2],
-			     ((VisuElement*)pos->data)->rgb[3],
-			     ((VisuElement*)pos->data)->material[0],
-			     ((VisuElement*)pos->data)->material[1],
-			     ((VisuElement*)pos->data)->material[2],
-			     ((VisuElement*)pos->data)->material[3],
-			     ((VisuElement*)pos->data)->material[4]);
-      pos = g_list_next(pos);
-    }
-  g_string_append_printf(data, "# %s\n", DESC_ELEMENT_PROPERTIES);
-  if (dataObj)
-    pos = eleList;
-  else
-    pos = (GList*)visu_element_getAllElements();
-  while(pos)
-    {
-      g_string_append_printf(data, "%s:\n", FLAG_ELEMENT_PROPERTIES);
-      g_string_append_printf(data, "    %s %d %d\n",
-			     ((VisuElement*)pos->data)->name,
-			     ((VisuElement*)pos->data)->rendered,
-			     ((VisuElement*)pos->data)->sensitiveToMaskingPlanes);
-      pos = g_list_next(pos);
-    }
-  g_string_append_printf(data, "\n");
-  if (eleList)
-    g_list_free(eleList);
+    eleList = g_list_copy((GList*)visu_element_getAllElements());
+  for (pos = eleList; pos; pos = g_list_next(pos))
+    visu_config_file_exportEntry(data, FLAG_ELEMENT_COLOR, ((VisuElement*)pos->data)->name,
+                                 "%4.3f %4.3f %4.3f %4.3f   %4.2f %4.2f %4.2f %4.2f %4.2f",
+                                 ((VisuElement*)pos->data)->rgb[0],
+                                 ((VisuElement*)pos->data)->rgb[1],
+                                 ((VisuElement*)pos->data)->rgb[2],
+                                 ((VisuElement*)pos->data)->rgb[3],
+                                 ((VisuElement*)pos->data)->material[0],
+                                 ((VisuElement*)pos->data)->material[1],
+                                 ((VisuElement*)pos->data)->material[2],
+                                 ((VisuElement*)pos->data)->material[3],
+                                 ((VisuElement*)pos->data)->material[4]);
+  visu_config_file_exportComment(data, DESC_ELEMENT_PROPERTIES);
+  for (pos = eleList; pos; pos = g_list_next(pos))
+    visu_config_file_exportEntry(data, FLAG_ELEMENT_PROPERTIES,
+                                 ((VisuElement*)pos->data)->name,
+                                 "%d %d", ((VisuElement*)pos->data)->rendered,
+                                 ((VisuElement*)pos->data)->sensitiveToPlanes);
+  g_list_free(eleList);
+  visu_config_file_exportComment(data, "");
 }
